@@ -1,23 +1,23 @@
 # -*- coding: utf-8
 
-__version__ = '0.3.4 - Darwin\'s Delight'
+__version__ = '0.4.1 - User\'s Universe'
 
-# tespy data and connection import
+# tespy data and connections import
 from . import connections  # noqa: F401
 from . import data  # noqa: F401
 # tespy components imports
 from .components import basics  # noqa: F401
 from .components import combustion  # noqa: F401
-from .components import components  # noqa: F401
+from .components import component  # noqa: F401
 from .components import heat_exchangers  # noqa: F401
 from .components import nodes  # noqa: F401
 from .components import piping  # noqa: F401
 from .components import reactors  # noqa: F401
-from .components import subsystems  # noqa: F401
+from .components import subsystem  # noqa: F401
 from .components import turbomachinery  # noqa: F401
 # tespy networks imports
+from .networks import network  # noqa: F401
 from .networks import network_reader  # noqa: F401
-from .networks import networks  # noqa: F401
 # tespy tools imports
 from .tools import characteristics  # noqa: F401
 from .tools import data_containers  # noqa: F401
