@@ -1,105 +1,107 @@
-from tespy.components import compressor
-from tespy.components import condenser
-from tespy.components import cycle_closer
-from tespy.components import drum
-from tespy.components import heat_exchanger
-from tespy.components import heat_exchanger_simple
-from tespy.components import pump
-from tespy.components import sink
-from tespy.components import source
-from tespy.components import valve
-from tespy.connections import connection
-from tespy.connections import ref
-from tespy.networks import network
-from tespy.tools.characteristics import char_line
+# -*- coding: utf-8 -*-
+
+from tespy.components import Compressor
+from tespy.components import Condenser
+from tespy.components import CycleCloser
+from tespy.components import Drum
+from tespy.components import HeatExchanger
+from tespy.components import HeatExchangerSimple
+from tespy.components import Pump
+from tespy.components import Sink
+from tespy.components import Source
+from tespy.components import Valve
+from tespy.connections import Connection
+from tespy.connections import Ref
+from tespy.networks import Network
+from tespy.tools.characteristics import CharLine
 from tespy.tools.characteristics import load_default_char as ldc
 
 # %% network
 
-nw = network(fluids=['water', 'NH3'], T_unit='C', p_unit='bar',
+nw = Network(fluids=['water', 'NH3'], T_unit='C', p_unit='bar',
              h_unit='kJ / kg', m_unit='kg / s')
 
 # %% components
 
 # sources & sinks
 
-cool_closer = cycle_closer('coolant cycle closer')
-cons_closer = cycle_closer('consumer cycle closer')
+cool_closer = CycleCloser('coolant cycle closer')
+cons_closer = CycleCloser('consumer cycle closer')
 
-amb_in = source('source ambient')
-amb_out = sink('sink ambient')
+amb_in = Source('source ambient')
+amb_out = Sink('sink ambient')
 
-ic_in = source('source intercool')
-ic_out = sink('sink intercool')
+ic_in = Source('source intercool')
+ic_out = Sink('sink intercool')
 
 # consumer system
 
-cd = condenser('condenser')
-rp = pump('recirculation pump')
-cons = heat_exchanger_simple('consumer')
+cd = Condenser('condenser')
+rp = Pump('recirculation pump')
+cons = HeatExchangerSimple('consumer')
 
 # evaporator system
 
-va = valve('valve')
-dr = drum('drum')
-ev = heat_exchanger('evaporator')
-su = heat_exchanger('superheater')
-pu = pump('pump evaporator')
+va = Valve('valve')
+dr = Drum('drum')
+ev = HeatExchanger('evaporator')
+su = HeatExchanger('superheater')
+pu = Pump('pump evaporator')
 
 # compressor-system
 
-cp1 = compressor('compressor 1')
-cp2 = compressor('compressor 2')
-he = heat_exchanger('intercooler')
+cp1 = Compressor('compressor 1')
+cp2 = Compressor('compressor 2')
+he = HeatExchanger('intercooler')
 
 # %% connections
 
 # consumer system
 
-c_in_cd = connection(cool_closer, 'out1', cd, 'in1')
-close_rp = connection(cons_closer, 'out1', rp, 'in1')
-rp_cd = connection(rp, 'out1', cd, 'in2')
-cd_cons = connection(cd, 'out2', cons, 'in1')
-cons_close = connection(cons, 'out1', cons_closer, 'in1')
+c_in_cd = Connection(cool_closer, 'out1', cd, 'in1')
+close_rp = Connection(cons_closer, 'out1', rp, 'in1')
+rp_cd = Connection(rp, 'out1', cd, 'in2')
+cd_cons = Connection(cd, 'out2', cons, 'in1')
+cons_close = Connection(cons, 'out1', cons_closer, 'in1')
 
 nw.add_conns(c_in_cd, close_rp, rp_cd, cd_cons, cons_close)
 
 # connection condenser - evaporator system
 
-cd_va = connection(cd, 'out1', va, 'in1')
+cd_va = Connection(cd, 'out1', va, 'in1')
 
 nw.add_conns(cd_va)
 
 # evaporator system
 
-va_dr = connection(va, 'out1', dr, 'in1')
-dr_pu = connection(dr, 'out1', pu, 'in1')
-pu_ev = connection(pu, 'out1', ev, 'in2')
-ev_dr = connection(ev, 'out2', dr, 'in2')
-dr_su = connection(dr, 'out2', su, 'in2')
+va_dr = Connection(va, 'out1', dr, 'in1')
+dr_pu = Connection(dr, 'out1', pu, 'in1')
+pu_ev = Connection(pu, 'out1', ev, 'in2')
+ev_dr = Connection(ev, 'out2', dr, 'in2')
+dr_su = Connection(dr, 'out2', su, 'in2')
 
 nw.add_conns(va_dr, dr_pu, pu_ev, ev_dr, dr_su)
 
-amb_in_su = connection(amb_in, 'out1', su, 'in1')
-su_ev = connection(su, 'out1', ev, 'in1')
-ev_amb_out = connection(ev, 'out1', amb_out, 'in1')
+amb_in_su = Connection(amb_in, 'out1', su, 'in1')
+su_ev = Connection(su, 'out1', ev, 'in1')
+ev_amb_out = Connection(ev, 'out1', amb_out, 'in1')
 
 nw.add_conns(amb_in_su, su_ev, ev_amb_out)
 
 # connection evaporator system - compressor system
 
-su_cp1 = connection(su, 'out2', cp1, 'in1')
+su_cp1 = Connection(su, 'out2', cp1, 'in1')
 
 nw.add_conns(su_cp1)
 
 # compressor-system
 
-cp1_he = connection(cp1, 'out1', he, 'in1')
-he_cp2 = connection(he, 'out1', cp2, 'in1')
-cp2_close = connection(cp2, 'out1', cool_closer, 'in1')
+cp1_he = Connection(cp1, 'out1', he, 'in1')
+he_cp2 = Connection(he, 'out1', cp2, 'in1')
+cp2_close = Connection(cp2, 'out1', cool_closer, 'in1')
 
-ic_in_he = connection(ic_in, 'out1', he, 'in2')
-he_ic_out = connection(he, 'out2', ic_out, 'in1')
+ic_in_he = Connection(ic_in, 'out1', he, 'in2')
+he_ic_out = Connection(he, 'out2', ic_out, 'in1')
 
 nw.add_conns(cp1_he, he_cp2, ic_in_he, he_ic_out, cp2_close)
 
@@ -114,8 +116,8 @@ cons.set_attr(pr=0.99, design=['pr'], offdesign=['zeta'])
 
 # evaporator system
 
-kA_char1 = ldc('heat exchanger', 'kA_char1', 'DEFAULT', char_line)
-kA_char2 = ldc('heat exchanger', 'kA_char2', 'EVAPORATING FLUID', char_line)
+kA_char1 = ldc('heat exchanger', 'kA_char1', 'DEFAULT', CharLine)
+kA_char2 = ldc('heat exchanger', 'kA_char2', 'EVAPORATING FLUID', CharLine)
 
 ev.set_attr(pr1=0.99, pr2=0.99, ttd_l=5,
             kA_char1=kA_char1, kA_char2=kA_char2,
@@ -142,7 +144,7 @@ cd_cons.set_attr(T=90)
 
 # evaporator system cold side
 
-pu_ev.set_attr(m=ref(va_dr, 0.75, 0), p0=5)
+pu_ev.set_attr(m=Ref(va_dr, 0.75, 0), p0=5)
 su_cp1.set_attr(p0=5, state='g')
 
 # evaporator system hot side
